# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, TypedDict

from .content_block_param import ContentBlockParam

__all__ = ["ResponseCreateParams", "Input", "Tool"]


class ResponseCreateParams(TypedDict, total=False):
    input: Iterable[Input]

    instructions: str

    max_output_tokens: int

    model: str

    previous_response_id: str

    stream: bool

    temperature: float

    tools: Iterable[Tool]

    top_p: float


class Input(TypedDict, total=False):
    call_id: str

    content: Iterable[ContentBlockParam]

    output: ContentBlockParam

    role: str

    type: Literal["computer_call_output"]


class Tool(TypedDict, total=False):
    display_height: int

    display_width: int

    environment: str

    type: Literal["computer_use"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["V2GoBackendInternalServiceResponsesUsage"]


class V2GoBackendInternalServiceResponsesUsage(BaseModel):
    input_tokens: Optional[int] = None

    output_tokens: Optional[int] = None

    total_tokens: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_result import ActionResult as ActionResult
from .content_block import ContentBlock as ContentBlock
from .computer_response import ComputerResponse as ComputerResponse
from .responses_response import ResponsesResponse as ResponsesResponse
from .content_block_param import ContentBlockParam as ContentBlockParam
from .computer_drag_params import ComputerDragParams as ComputerDragParams
from .computer_html_params import ComputerHTMLParams as ComputerHTMLParams
from .computer_list_params import ComputerListParams as ComputerListParams
from .computer_type_params import ComputerTypeParams as ComputerTypeParams
from .computer_action_param import ComputerActionParam as ComputerActionParam
from .computer_batch_params import ComputerBatchParams as ComputerBatchParams
from .computer_click_params import ComputerClickParams as ComputerClickParams
from .computer_debug_params import ComputerDebugParams as ComputerDebugParams
from .computer_create_params import ComputerCreateParams as ComputerCreateParams
from .computer_hotkey_params import ComputerHotkeyParams as ComputerHotkeyParams
from .computer_key_up_params import ComputerKeyUpParams as ComputerKeyUpParams
from .computer_list_response import ComputerListResponse as ComputerListResponse
from .computer_scroll_params import ComputerScrollParams as ComputerScrollParams
from .response_create_params import ResponseCreateParams as ResponseCreateParams
from .computer_batch_response import ComputerBatchResponse as ComputerBatchResponse
from .computer_execute_params import ComputerExecuteParams as ComputerExecuteParams
from .computer_key_down_params import ComputerKeyDownParams as ComputerKeyDownParams
from .computer_mouse_up_params import ComputerMouseUpParams as ComputerMouseUpParams
from .computer_navigate_params import ComputerNavigateParams as ComputerNavigateParams
from .computer_viewport_params import ComputerViewportParams as ComputerViewportParams
from .response_delete_response import ResponseDeleteResponse as ResponseDeleteResponse
from .computer_mouse_down_params import ComputerMouseDownParams as ComputerMouseDownParams
from .computer_screenshot_params import ComputerScreenshotParams as ComputerScreenshotParams
from .computer_keepalive_response import ComputerKeepaliveResponse as ComputerKeepaliveResponse
from .computer_right_click_params import ComputerRightClickParams as ComputerRightClickParams
from .computer_change_proxy_params import ComputerChangeProxyParams as ComputerChangeProxyParams
from .computer_double_click_params import ComputerDoubleClickParams as ComputerDoubleClickParams
from .computer_retrieve_status_response import ComputerRetrieveStatusResponse as ComputerRetrieveStatusResponse
from .v2_go_backend_internal_service_action import V2GoBackendInternalServiceAction as V2GoBackendInternalServiceAction
from .v2_go_backend_internal_service_viewport import (
    V2GoBackendInternalServiceViewport as V2GoBackendInternalServiceViewport,
)
from .v2_go_backend_internal_types_page_context import (
    V2GoBackendInternalTypesPageContext as V2GoBackendInternalTypesPageContext,
)
from .v2_go_backend_internal_service_output_item import (
    V2GoBackendInternalServiceOutputItem as V2GoBackendInternalServiceOutputItem,
)
from .v2_go_backend_internal_service_responses_usage import (
    V2GoBackendInternalServiceResponsesUsage as V2GoBackendInternalServiceResponsesUsage,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .v2_go_backend_internal_service_viewport import V2GoBackendInternalServiceViewport
from .v2_go_backend_internal_service_output_item import V2GoBackendInternalServiceOutputItem
from .v2_go_backend_internal_service_responses_usage import V2GoBackendInternalServiceResponsesUsage

__all__ = ["ResponsesResponse"]


class ResponsesResponse(BaseModel):
    id: Optional[str] = None

    computer_id: Optional[str] = None

    created_at: Optional[str] = None

    max_output_tokens: Optional[int] = None

    model: Optional[str] = None

    object: Optional[str] = None

    output: Optional[List[V2GoBackendInternalServiceOutputItem]] = None

    status: Optional[str] = None

    temperature: Optional[float] = None

    top_p: Optional[float] = None

    usage: Optional[V2GoBackendInternalServiceResponsesUsage] = None

    viewport: Optional[V2GoBackendInternalServiceViewport] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel
from .content_block import ContentBlock
from .v2_go_backend_internal_service_action import V2GoBackendInternalServiceAction

__all__ = ["V2GoBackendInternalServiceOutputItem"]


class V2GoBackendInternalServiceOutputItem(BaseModel):
    id: Optional[str] = None

    action: Optional[V2GoBackendInternalServiceAction] = None

    call_id: Optional[str] = None

    content: Optional[List[ContentBlock]] = None

    role: Optional[str] = None

    status: Optional[str] = None

    summary: Optional[List[ContentBlock]] = None

    type: Optional[Literal["reasoning", "computer_call", "computer_call_output", "message"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tzafon import Lightcone, AsyncLightcone
from tests.utils import assert_matches_type
from tzafon.types import ResponsesResponse, ResponseDeleteResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestResponses:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Lightcone) -> None:
        response = client.responses.create()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Lightcone) -> None:
        response = client.responses.create(
            input=[
                {
                    "call_id": "call_id",
                    "content": [
                        {
                            "image_url": "image_url",
                            "text": "text",
                            "type": "input_text",
                        }
                    ],
                    "output": {
                        "image_url": "image_url",
                        "text": "text",
                        "type": "input_text",
                    },
                    "role": "role",
                    "type": "computer_call_output",
                }
            ],
            instructions="instructions",
            max_output_tokens=0,
            model="model",
            previous_response_id="previous_response_id",
            stream=True,
            temperature=0,
            tools=[
                {
                    "display_height": 0,
                    "display_width": 0,
                    "environment": "environment",
                    "type": "computer_use",
                }
            ],
            top_p=0,
        )
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Lightcone) -> None:
        http_response = client.responses.with_raw_response.create()

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = http_response.parse()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Lightcone) -> None:
        with client.responses.with_streaming_response.create() as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = http_response.parse()
            assert_matches_type(ResponsesResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Lightcone) -> None:
        response = client.responses.retrieve(
            "id",
        )
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Lightcone) -> None:
        http_response = client.responses.with_raw_response.retrieve(
            "id",
        )

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = http_response.parse()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Lightcone) -> None:
        with client.responses.with_streaming_response.retrieve(
            "id",
        ) as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = http_response.parse()
            assert_matches_type(ResponsesResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Lightcone) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.responses.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: Lightcone) -> None:
        response = client.responses.delete(
            "id",
        )
        assert_matches_type(ResponseDeleteResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Lightcone) -> None:
        http_response = client.responses.with_raw_response.delete(
            "id",
        )

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = http_response.parse()
        assert_matches_type(ResponseDeleteResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Lightcone) -> None:
        with client.responses.with_streaming_response.delete(
            "id",
        ) as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = http_response.parse()
            assert_matches_type(ResponseDeleteResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Lightcone) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.responses.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_cancel(self, client: Lightcone) -> None:
        response = client.responses.cancel(
            "id",
        )
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_cancel(self, client: Lightcone) -> None:
        http_response = client.responses.with_raw_response.cancel(
            "id",
        )

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = http_response.parse()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_cancel(self, client: Lightcone) -> None:
        with client.responses.with_streaming_response.cancel(
            "id",
        ) as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = http_response.parse()
            assert_matches_type(ResponsesResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_cancel(self, client: Lightcone) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.responses.with_raw_response.cancel(
                "",
            )


class TestAsyncResponses:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncLightcone) -> None:
        response = await async_client.responses.create()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncLightcone) -> None:
        response = await async_client.responses.create(
            input=[
                {
                    "call_id": "call_id",
                    "content": [
                        {
                            "image_url": "image_url",
                            "text": "text",
                            "type": "input_text",
                        }
                    ],
                    "output": {
                        "image_url": "image_url",
                        "text": "text",
                        "type": "input_text",
                    },
                    "role": "role",
                    "type": "computer_call_output",
                }
            ],
            instructions="instructions",
            max_output_tokens=0,
            model="model",
            previous_response_id="previous_response_id",
            stream=True,
            temperature=0,
            tools=[
                {
                    "display_height": 0,
                    "display_width": 0,
                    "environment": "environment",
                    "type": "computer_use",
                }
            ],
            top_p=0,
        )
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncLightcone) -> None:
        http_response = await async_client.responses.with_raw_response.create()

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = await http_response.parse()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncLightcone) -> None:
        async with async_client.responses.with_streaming_response.create() as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = await http_response.parse()
            assert_matches_type(ResponsesResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncLightcone) -> None:
        response = await async_client.responses.retrieve(
            "id",
        )
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncLightcone) -> None:
        http_response = await async_client.responses.with_raw_response.retrieve(
            "id",
        )

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = await http_response.parse()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncLightcone) -> None:
        async with async_client.responses.with_streaming_response.retrieve(
            "id",
        ) as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = await http_response.parse()
            assert_matches_type(ResponsesResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncLightcone) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.responses.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncLightcone) -> None:
        response = await async_client.responses.delete(
            "id",
        )
        assert_matches_type(ResponseDeleteResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncLightcone) -> None:
        http_response = await async_client.responses.with_raw_response.delete(
            "id",
        )

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = await http_response.parse()
        assert_matches_type(ResponseDeleteResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncLightcone) -> None:
        async with async_client.responses.with_streaming_response.delete(
            "id",
        ) as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = await http_response.parse()
            assert_matches_type(ResponseDeleteResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncLightcone) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.responses.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_cancel(self, async_client: AsyncLightcone) -> None:
        response = await async_client.responses.cancel(
            "id",
        )
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_cancel(self, async_client: AsyncLightcone) -> None:
        http_response = await async_client.responses.with_raw_response.cancel(
            "id",
        )

        assert http_response.is_closed is True
        assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"
        response = await http_response.parse()
        assert_matches_type(ResponsesResponse, response, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_cancel(self, async_client: AsyncLightcone) -> None:
        async with async_client.responses.with_streaming_response.cancel(
            "id",
        ) as http_response:
            assert not http_response.is_closed
            assert http_response.http_request.headers.get("X-Stainless-Lang") == "python"

            response = await http_response.parse()
            assert_matches_type(ResponsesResponse, response, path=["response"])

        assert cast(Any, http_response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_cancel(self, async_client: AsyncLightcone) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.responses.with_raw_response.cancel(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ContentBlockParam"]


class ContentBlockParam(TypedDict, total=False):
    image_url: str

    text: str

    type: Literal["input_text", "output_text", "summary_text", "input_image"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["V2GoBackendInternalServiceViewport"]


class V2GoBackendInternalServiceViewport(BaseModel):
    environment: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..types import response_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.responses_response import ResponsesResponse
from ..types.response_delete_response import ResponseDeleteResponse

__all__ = ["ResponsesResource", "AsyncResponsesResource"]


class ResponsesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ResponsesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tzafon/lightcone-python#accessing-raw-response-data-eg-headers
        """
        return ResponsesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ResponsesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tzafon/lightcone-python#with_streaming_response
        """
        return ResponsesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        input: Iterable[response_create_params.Input] | Omit = omit,
        instructions: str | Omit = omit,
        max_output_tokens: int | Omit = omit,
        model: str | Omit = omit,
        previous_response_id: str | Omit = omit,
        stream: bool | Omit = omit,
        temperature: float | Omit = omit,
        tools: Iterable[response_create_params.Tool] | Omit = omit,
        top_p: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponsesResponse:
        """Create a model response.

        Supports text conversations and computer-use (CUA)
        workflows. Set stream=true for server-sent events. Include tools with type
        "computer_use" for CUA mode, which returns structured computer_call actions. Use
        previous_response_id to chain multi-turn conversations.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/responses",
            body=maybe_transform(
                {
                    "input": input,
                    "instructions": instructions,
                    "max_output_tokens": max_output_tokens,
                    "model": model,
                    "previous_response_id": previous_response_id,
                    "stream": stream,
                    "temperature": temperature,
                    "tools": tools,
                    "top_p": top_p,
                },
                response_create_params.ResponseCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponsesResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponsesResponse:
        """
        Retrieve a previously created response by its ID, including all output items.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/responses/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponsesResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponseDeleteResponse:
        """
        Permanently delete a response and all its output items.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/responses/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponseDeleteResponse,
        )

    def cancel(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponsesResponse:
        """Cancel an in-progress response.

        Only responses with status "in_progress" can be
        cancelled.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/responses/{id}/cancel",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponsesResponse,
        )


class AsyncResponsesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncResponsesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/tzafon/lightcone-python#accessing-raw-response-data-eg-headers
        """
        return AsyncResponsesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncResponsesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/tzafon/lightcone-python#with_streaming_response
        """
        return AsyncResponsesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        input: Iterable[response_create_params.Input] | Omit = omit,
        instructions: str | Omit = omit,
        max_output_tokens: int | Omit = omit,
        model: str | Omit = omit,
        previous_response_id: str | Omit = omit,
        stream: bool | Omit = omit,
        temperature: float | Omit = omit,
        tools: Iterable[response_create_params.Tool] | Omit = omit,
        top_p: float | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponsesResponse:
        """Create a model response.

        Supports text conversations and computer-use (CUA)
        workflows. Set stream=true for server-sent events. Include tools with type
        "computer_use" for CUA mode, which returns structured computer_call actions. Use
        previous_response_id to chain multi-turn conversations.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/responses",
            body=await async_maybe_transform(
                {
                    "input": input,
                    "instructions": instructions,
                    "max_output_tokens": max_output_tokens,
                    "model": model,
                    "previous_response_id": previous_response_id,
                    "stream": stream,
                    "temperature": temperature,
                    "tools": tools,
                    "top_p": top_p,
                },
                response_create_params.ResponseCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponsesResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponsesResponse:
        """
        Retrieve a previously created response by its ID, including all output items.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/responses/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponsesResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponseDeleteResponse:
        """
        Permanently delete a response and all its output items.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/responses/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponseDeleteResponse,
        )

    async def cancel(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ResponsesResponse:
        """Cancel an in-progress response.

        Only responses with status "in_progress" can be
        cancelled.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/responses/{id}/cancel",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ResponsesResponse,
        )


class ResponsesResourceWithRawResponse:
    def __init__(self, responses: ResponsesResource) -> None:
        self._responses = responses

        self.create = to_raw_response_wrapper(
            responses.create,
        )
        self.retrieve = to_raw_response_wrapper(
            responses.retrieve,
        )
        self.delete = to_raw_response_wrapper(
            responses.delete,
        )
        self.cancel = to_raw_response_wrapper(
            responses.cancel,
        )


class AsyncResponsesResourceWithRawResponse:
    def __init__(self, responses: AsyncResponsesResource) -> None:
        self._responses = responses

        self.create = async_to_raw_response_wrapper(
            responses.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            responses.retrieve,
        )
        self.delete = async_to_raw_response_wrapper(
            responses.delete,
        )
        self.cancel = async_to_raw_response_wrapper(
            responses.cancel,
        )


class ResponsesResourceWithStreamingResponse:
    def __init__(self, responses: ResponsesResource) -> None:
        self._responses = responses

        self.create = to_streamed_response_wrapper(
            responses.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            responses.retrieve,
        )
        self.delete = to_streamed_response_wrapper(
            responses.delete,
        )
        self.cancel = to_streamed_response_wrapper(
            responses.cancel,
        )


class AsyncResponsesResourceWithStreamingResponse:
    def __init__(self, responses: AsyncResponsesResource) -> None:
        self._responses = responses

        self.create = async_to_streamed_response_wrapper(
            responses.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            responses.retrieve,
        )
        self.delete = async_to_streamed_response_wrapper(
            responses.delete,
        )
        self.cancel = async_to_streamed_response_wrapper(
            responses.cancel,
        )
